[sawfish] A new faq item on how to execute applications.



commit 670da8b221a4682de699b36f5d045068de77a5e2
Author: Teika kazura <teika lavabit com>
Date:   Sun Jun 20 21:36:06 2010 +0900

    A new faq item on how to execute applications.

 lisp/sawfish/wm/commands.jl |    6 +++---
 man/faq.texi                |   24 ++++++++++++++++++------
 man/news.texi               |    2 +-
 3 files changed, 22 insertions(+), 10 deletions(-)
---
diff --git a/man/faq.texi b/man/faq.texi
index 34eb2b1..4c15b20 100644
--- a/man/faq.texi
+++ b/man/faq.texi
@@ -66,12 +66,24 @@ Sawfish < 1.6 reads @file{sawfish-defaults} by default only if
 @file{~/.sawfishrc} lacks, but now it is always read.
 @end table
 
- item How do I bind a key to execute a shell command?
-
-Bind a key to the @samp{run-shell-command} command; remember to enter
-the shell command you want to execute in the string entry in the
- samp{Edit binding} dialog window.
-
+ item How can I start an application from Sawfish?
+ itemize @bullet
+ item From a key @*
+Bind a key to the @samp{run-shell-command} command. In the
+configurator, you can enter the command name at the same time.
+
+ item From lisp @*
+The function @code{system} invokes a shell. Don't forget to add ``&''
+not to block the Sawfish execution.
+ lisp
+(system "firefox doodle.com &")
+ end lisp
+
+ item At Sawfish startup @*
+You can use lisp, but you don't have to. Simply execute it from, say,
+ file{ Xclient} or any file. See the above item ``How do I customize
+Sawfish?'' for lisp customization.
+ end itemize
 
 @item How do I make clicking on a window raise the window?
 
diff --git a/man/news.texi b/man/news.texi
index 2452c6b..eca6a50 100644
--- a/man/news.texi
+++ b/man/news.texi
@@ -26,7 +26,7 @@ parts. (@pxref{Frame Part Definition})
 @item Miscellaneous Changes
 @itemize @minus
 @item Doc improvements *
-A new faq item on how to hide the mouse pointer  *
+Faq items, on how to hide the mouse pointer, and on application execution  *
 Manuals (1) describe all options.
 @end itemize
 @end itemize



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/lisp/sawfish/wm/commands.jl b/lisp/sawfish/wm/commands.jl
index 09ac4ca..7822825 100644
--- a/lisp/sawfish/wm/commands.jl
+++ b/lisp/sawfish/wm/commands.jl
@@ -363,14 +363,14 @@ command called NAME (optionally whose arguments have custom-type TYPE)."
 ;;; some default commands
 
   (define (run-shell-command command)
-    "Execute a shell command. This is a wrapper command for the
-`system' function."
+    "Execute a shell command in the background. This is a wrapper
+command for the `system' function."
     (system (format nil "%s &" command)))
 
   (define-command 'run-shell-command run-shell-command
     #:spec "sCommand:"
     #:type `(and (labelled ,(_ "Command:") string))
     #:doc "Execute the given shell command.")
 
   (define (command-sequence commands)
     "Invoke the list of commands, one by one."
@@ -363,14 +363,14 @@ command called NAME (optionally whose arguments have custom-type TYPE)."
     #:spec "sCommand:"
     #:type `(and (labelled ,(_ "Command:") string))
-    #:doc "Execute the given shell command.")
+    #:doc "Execute the given shell command in the background.")
 
   (define (command-sequence commands)